/*	TestDockExtra.h
	By Jens Ayton
	
	
	Hacked-together "Dock Extra", allowing an app to display a custom dock icon
	under Leopard while not running. Very much not guaranteed to work with
	future system updates, or at all.
	
	Testing note: dock extras are not unloaded when the application is removed
	from the dock. To test modifications, use "killall SystemUIServer".
	(No, really.)
	
	This code is hereby placed in the public domain.
*/


#import "TestDockExtra.h"


@interface TestDockExtra ()
- (void) draw;
@end


@implementation TestDockExtra

- (id) init
{
	/*	Called on set-up in the usual way. Draw here, and set up timers or
		anything else needed to modify drawing over time.
		
		Note delayed call of draw: if we draw immediately in -init, nothing
		happens.
	*/
	self = [super init];
	[self performSelector:@selector(draw)
			   withObject:nil
			   afterDelay:0];
	return self;
}


- (void) invalidate
{
	// Called when removed from dock. Clean up here.
	[super invalidate];
}


- (void) draw
{
	NSGraphicsContext			*context = nil;
	NSRect						frame = NSZeroRect;
	NSBezierPath				*path = nil;
	
	// Get graphics context and size from SystemUIServer.
	context = [self getContext:&frame.size];
	if (context == nil)  return;
	
	// Save
	[NSGraphicsContext saveGraphicsState];
	[NSGraphicsContext setCurrentContext:context];
	
	// Draw
	path = [NSBezierPath bezierPathWithOvalInRect:frame];
	[[NSColor greenColor] set];
	[path fill];
	
	// Restore
	[NSGraphicsContext restoreGraphicsState];
	
	// Apply drawing to dock
	[self setDockImageFromContext];
	
	// clean up
	[self releaseContext];
}

@end
